--- asterisk.c.orig	Fri Mar 25 22:15:53 2005
+++ asterisk.c	Fri Mar 25 22:16:27 2005
@@ -54,6 +54,7 @@
 
 #if  defined(__FreeBSD__) || defined( __NetBSD__ ) || defined(SOLARIS)
 #include <netdb.h>
+#include <sys/rtprio.h>
 #endif
 
 #ifndef AF_LOCAL
@@ -540,11 +541,11 @@
 
 static int set_priority(int pri)
 {
-	struct sched_param sched;
-	memset(&sched, 0, sizeof(sched));
 	/* We set ourselves to a high priority, that we might pre-empt everything
 	   else.  If your PBX has heavy activity on it, this is a good thing.  */
 #ifdef __linux__
+	struct sched_param sched;
+	memset(&sched, 0, sizeof(sched));
 	if (pri) {  
 		sched.sched_priority = 10;
 		if (sched_setscheduler(0, SCHED_RR, &sched)) {
@@ -556,6 +557,25 @@
 	} else {
 		sched.sched_priority = 0;
 		if (sched_setscheduler(0, SCHED_OTHER, &sched)) {
+			ast_log(LOG_WARNING, "Unable to set normal priority\n");
+			return -1;
+		}
+	}
+#elif defined(__FreeBSD__)
+	struct rtprio rtp;
+	if (pri) {
+		rtp.type = RTP_PRIO_REALTIME;
+		rtp.prio = 0;
+		if (rtprio(RTP_SET, 0, &rtp) == -1) {
+			ast_log(LOG_WARNING, "Unable to set high priority\n");
+			return -1;
+		} else
+			if (option_verbose)
+				ast_verbose("Set to high priority\n");
+	} else {
+		rtp.type = RTP_PRIO_NORMAL;
+		rtp.prio = 0;
+		if (rtprio(RTP_SET, 0, &rtp) == -1) {
 			ast_log(LOG_WARNING, "Unable to set normal priority\n");
 			return -1;
 		}
